Contributing to BlueCelluLab
============================

Thank you for taking the time to contribute!

Reporting Bugs and Suggesting Enhancements
------------------------------------------

1. Search existing `issues <https://github.com/BlueBrain/BlueCelluLab/issues>`_.
2. Open a new issue with a clear title and detailed description.
3. Include steps to reproduce, expected and actual behavior for bugs, or the current and expected behavior for enhancements.
4. Attach any relevant screenshots or files.
5. If applicable specify the versions of BlueCelluLab, Python and any relevant dependencies.

Pull Requests
-------------

1. Fork the repository and create a new branch.
2. Make your changes.
3. Run `tox -e lint` to check the code format.
4. Run the tests with `tox -e py3`.
5. Add unit tests for the new code.
6. If applicable add type hints and docstrings.
7. If applicable update the documentation.
8. Submit a pull request with a clear description.

Thank you for contributing to BlueCelluLab!
